use std::ops::Deref;

use news_flash::models::{ArticleFilter, ArticleID, CategoryID, FeedID, TagID};

use crate::app::App;

#[derive(Debug, Clone)]
pub enum MarkAllReadSource {
    All,
    Feed(FeedID),
    Category(CategoryID),
    Tag(TagID),
    Custom(Box<ArticleFilter>),
}

#[derive(Debug, Clone)]
pub struct UndoMarkReadAction {
    pub source_action: MarkAllReadSource,
    pub article_ids: Vec<ArticleID>,
}

impl UndoMarkReadAction {
    pub fn execute(self) {
        App::default()
            .main_window()
            .content_page()
            .article_list_column()
            .start_mark_all_read();

        match self.source_action {
            MarkAllReadSource::All => App::set_all_read(),
            MarkAllReadSource::Feed(feed_id) => App::set_feed_read(&feed_id),
            MarkAllReadSource::Category(category_id) => App::set_category_read(&category_id),
            MarkAllReadSource::Tag(tag_id) => App::set_tag_read(&tag_id),
            MarkAllReadSource::Custom(filter) => App::set_filter_read(filter.deref().clone()),
        }
    }
}
